@@ -16,7 +16,7 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.97 2006/08/07 18:46:22 kaffeetisch Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.99 2006/08/20 12:44:20 kaffeetisch Exp $
 #
 
 package Gtk2;
@@ -35,7 +35,7 @@ eval "use Cairo;";
 
 require DynaLoader;
 
-our $VERSION = '1.132';
+our $VERSION = '1.133';
 
 our @ISA = qw(DynaLoader);
 
@@ -127,18 +127,18 @@ Gtk2 - Perl interface to the 2.x series of the Gimp Toolkit library
 =head1 ABSTRACT
 
 Perl bindings to the 2.x series of the Gtk+ widget set.  This module
-allows you to write graphical user interfaces in a perlish and
+allows you to write graphical user interfaces in a Perlish and
 object-oriented way, freeing you from the casting and memory management
 in C, yet remaining very close in spirit to original API.
 
 =head1 DESCRIPTION
 
-The Gtk2 module allows a perl developer to use the Gtk+ graphical user
+The Gtk2 module allows a Perl developer to use the Gtk+ graphical user
 interface library.  Find out more about Gtk+ at http://www.gtk.org.
 
 The GTK+ Reference Manual is also a handy companion when writing Gtk
 programs in any language.  http://developer.gnome.org/doc/API/2.0/gtk/
-The perl bindings follow the C API very closely, and the C reference
+The Perl bindings follow the C API very closely, and the C reference
 documentation should be considered the canonical source.
 
 To discuss gtk2-perl, ask questions and flame/praise the authors,
@@ -180,8 +180,8 @@ L<perl>(1), L<Glib>(3pm).
 L<Gtk2::Gdk::Keysyms>(3pm) contains a hash of key codes, culled from
 gdk/gdkkeysyms.h
 
-L<Gtk2::api>(3pm) describes how to map the C API into perl, and some of the
-important differences in the perl bindings.
+L<Gtk2::api>(3pm) describes how to map the C API into Perl, and some of the
+important differences in the Perl bindings.
 
 L<Gtk2::Helper>(3pm) contains stuff that makes writing Gtk2 programs
 a little easier.
@@ -195,7 +195,7 @@ may need to work with pango directly.
 L<Gtk2::index>(3pm) lists the autogenerated api documentation pod files
 for Gtk2.
 
-Gtk2 also provides code to make it relatively painless to create perl
+Gtk2 also provides code to make it relatively painless to create Perl
 wrappers for other GLib/Gtk-based libraries.  See L<Gtk2::CodeGen>,
 L<ExtUtils::PkgConfig>, and L<ExtUtils::Depends>.  If you're writing bindings,
 you'll probably also be interested in L<Gtk2::devel>, which is a supplement
